gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r29778 - in gnunet/src: conversation include postgres scala


From: gnunet
Subject: [GNUnet-SVN] r29778 - in gnunet/src: conversation include postgres scalarproduct
Date: Wed, 2 Oct 2013 00:17:21 +0200

Author: grothoff
Date: 2013-10-02 00:17:20 +0200 (Wed, 02 Oct 2013)
New Revision: 29778

Modified:
   gnunet/src/conversation/gnunet-service-conversation.c
   gnunet/src/include/gnunet_postgres_lib.h
   gnunet/src/include/winproc.h
   gnunet/src/postgres/postgres.c
   gnunet/src/scalarproduct/gnunet-service-scalarproduct.c
Log:
-spell param(eter) correctly


Modified: gnunet/src/conversation/gnunet-service-conversation.c
===================================================================
--- gnunet/src/conversation/gnunet-service-conversation.c       2013-10-01 
19:44:13 UTC (rev 29777)
+++ gnunet/src/conversation/gnunet-service-conversation.c       2013-10-01 
22:17:20 UTC (rev 29778)
@@ -967,8 +967,8 @@
 * Function to handle a initiation messaage incoming over mesh
  * @param cls closure, NULL
  * @param tunnel the tunnel over which the message arrived
- * @pram tunnel_ctx the tunnel context, can be NULL
- * @pram message the incoming message
+ * @param tunnel_ctx the tunnel context, can be NULL
+ * @param message the incoming message
  * 
  * @return GNUNET_OK
 */
@@ -1097,8 +1097,8 @@
 * Function to handle an accept messaage incoming over mesh
  * @param cls closure, NULL
  * @param tunnel the tunnel over which the message arrived
- * @pram tunnel_ctx the tunnel context, can be NULL
- * @pram message the incoming message
+ * @param tunnel_ctx the tunnel context, can be NULL
+ * @param message the incoming message
  * 
  * @return GNUNET_OK
 */
@@ -1177,8 +1177,8 @@
 * Function to handle a reject messaage incoming over mesh
  * @param cls closure, NULL
  * @param tunnel the tunnel over which the message arrived
- * @pram tunnel_ctx the tunnel context, can be NULL
- * @pram message the incoming message
+ * @param tunnel_ctx the tunnel context, can be NULL
+ * @param message the incoming message
  * 
  * @return GNUNET_OK
 */
@@ -1230,8 +1230,8 @@
 * Function to handle a terminate messaage incoming over mesh
  * @param cls closure, NULL
  * @param tunnel the tunnel over which the message arrived
- * @pram tunnel_ctx the tunnel context, can be NULL
- * @pram message the incoming message
+ * @param tunnel_ctx the tunnel context, can be NULL
+ * @param message the incoming message
  * 
  * @return GNUNET_OK
 */
@@ -1275,8 +1275,8 @@
 * Function to handle a audio messaage incoming over mesh
  * @param cls closure, NULL
  * @param tunnel the tunnel over which the message arrived
- * @pram tunnel_ctx the tunnel context, can be NULL
- * @pram message the incoming message
+ * @param tunnel_ctx the tunnel context, can be NULL
+ * @param message the incoming message
  * 
  * @return GNUNET_OK
 */

Modified: gnunet/src/include/gnunet_postgres_lib.h
===================================================================
--- gnunet/src/include/gnunet_postgres_lib.h    2013-10-01 19:44:13 UTC (rev 
29777)
+++ gnunet/src/include/gnunet_postgres_lib.h    2013-10-01 22:17:20 UTC (rev 
29778)
@@ -101,14 +101,14 @@
  * @param dbh database handle
  * @param name name for the prepared SQL statement
  * @param sql SQL code to prepare
- * @param nparms number of parameters in sql
+ * @param nparams number of parameters in sql
  * @param filename filename for error reporting
  * @param line code line for error reporting
  * @return GNUNET_OK on success
  */
 int
 GNUNET_POSTGRES_prepare_ (PGconn *dbh, const char *name, const char *sql,
-                         int nparms,
+                         int nparams,
                          const char *filename, int line);
 
 

Modified: gnunet/src/include/winproc.h
===================================================================
--- gnunet/src/include/winproc.h        2013-10-01 19:44:13 UTC (rev 29777)
+++ gnunet/src/include/winproc.h        2013-10-01 22:17:20 UTC (rev 29778)
@@ -112,7 +112,7 @@
   typedef NET_API_STATUS WINAPI (*TNetUserSetInfo) (LPCWSTR servername,
                                                     LPCWSTR username,
                                                     DWORD level, LPBYTE buf,
-                                                    LPDWORD parm_err);
+                                                    LPDWORD param_err);
   typedef NTSTATUS NTAPI (*TLsaOpenPolicy) (PLSA_UNICODE_STRING,
                                             PLSA_OBJECT_ATTRIBUTES, 
ACCESS_MASK,
                                             PLSA_HANDLE);

Modified: gnunet/src/postgres/postgres.c
===================================================================
--- gnunet/src/postgres/postgres.c      2013-10-01 19:44:13 UTC (rev 29777)
+++ gnunet/src/postgres/postgres.c      2013-10-01 22:17:20 UTC (rev 29778)
@@ -96,18 +96,18 @@
  * @param dbh database handle
  * @param name name for the prepared SQL statement
  * @param sql SQL code to prepare
  * @param nparms number of parameters in sql
  * @param filename filename for error reporting
  * @param line code line for error reporting
  * @return GNUNET_OK on success
  */
 int
 GNUNET_POSTGRES_prepare_ (PGconn * dbh, const char *name, const char *sql,
-                          int nparms, const char *filename, int line)
+                          int nparams, const char *filename, int line)
 {
   PGresult *ret;
 
-  ret = PQprepare (dbh, name, sql, nparms, NULL);
+  ret = PQprepare (dbh, name, sql, nparams, NULL);
   if (GNUNET_OK !=
       GNUNET_POSTGRES_check_result_ (dbh, ret, PGRES_COMMAND_OK, "PQprepare",
                                      sql, filename, line))

Modified: gnunet/src/scalarproduct/gnunet-service-scalarproduct.c
===================================================================
--- gnunet/src/scalarproduct/gnunet-service-scalarproduct.c     2013-10-01 
19:44:13 UTC (rev 29777)
+++ gnunet/src/scalarproduct/gnunet-service-scalarproduct.c     2013-10-01 
22:17:20 UTC (rev 29778)
@@ -271,7 +271,7 @@
 static void
 generate_keyset ()
 {
-  gcry_sexp_t gen_parms;
+  gcry_sexp_t gen_params;
   gcry_sexp_t key;
   gcry_sexp_t tmp_sexp;
   gcry_mpi_t p;
@@ -283,12 +283,12 @@
   size_t erroff = 0;
 
   // we can still use the RSA keygen for generating p,q,n, but using e is 
pointless.
-  GNUNET_assert (0 == gcry_sexp_build (&gen_parms, &erroff,
+  GNUNET_assert (0 == gcry_sexp_build (&gen_params, &erroff,
                                        "(genkey(rsa(nbits %d)(rsa-use-e 
3:257)))",
                                        KEYBITS));
 
-  GNUNET_assert (0 == gcry_pk_genkey (&key, gen_parms));
-  gcry_sexp_release (gen_parms);
+  GNUNET_assert (0 == gcry_pk_genkey (&key, gen_params));
+  gcry_sexp_release (gen_params);
 
   // get n and d of our publickey as MPI  
   tmp_sexp = gcry_sexp_find_token (key, "n", 0);
@@ -96,18 +96,18 @@
  * @param name name for the prepared SQL statement
  * @param sql SQL code to prepare
- * @param nparms number of parameters in sql
+ * @param nparams number of parameters in sql
  * @param filename filename for error reporting
  * @param line code line for error reporting




reply via email to

[Prev in Thread] Current Thread [Next in Thread]